@@ -1,8 +1,6 @@
 import ast
 from pathlib import Path
 from typing import List, Dict, Any
-from docstring_parser import parse as dsp
-import jsonschema
 
 def convert_python_type_to_json_schema(python_type: str) -> Dict[str, Any]:
     """将 Python 类型转换为 JSON Schema 类型
@@ -196,6 +194,8 @@ def validate_json_schema(schema: Dict[str, Any], context: str = "") -> None:
         ValueError: 当 schema 不符合规范时抛出异常
     """
     try:
+        # 延迟导入 jsonschema 避免模块级别的依赖问题
+        import jsonschema
         # 使用 JSON Schema Draft 7 验证器
         jsonschema.Draft7Validator.check_schema(schema)
         
@@ -217,8 +217,12 @@ def validate_json_schema(schema: Dict[str, Any], context: str = "") -> None:
         if "items" in schema:
             validate_json_schema(schema["items"], f"{context}.items" if context else "items")
             
-    except jsonschema.SchemaError as e:
-        raise ValueError(f"Invalid JSON Schema{f' in {context}' if context else ''}: {str(e)}")
+    except Exception as e:
+        # 检查是否是 jsonschema.SchemaError
+        if e.__class__.__name__ == 'SchemaError':
+            raise ValueError(f"Invalid JSON Schema{f' in {context}' if context else ''}: {str(e)}")
+        else:
+            raise e
 
 def convert_union_types(types: List[str]) -> Dict[str, Any]:
     """转换联合类型为 JSON Schema
@@ -263,6 +267,31 @@ def validate_description_length(description: str, function_name: str, file_path:
             f"超过了1024字符限制。请缩短描述长度。"
         )
 
+def _inherits_from_tool(class_node: ast.ClassDef) -> bool:
+    """检查类是否继承了 adam_community.Tool
+    
+    Args:
+        class_node: AST 类定义节点
+        
+    Returns:
+        bool: 如果类继承了 adam_community.Tool 则返回 True，否则返回 False
+    """
+    for base in class_node.bases:
+        if isinstance(base, ast.Name):
+            # 直接继承 Tool 类
+            if base.id == 'Tool':
+                return True
+        elif isinstance(base, ast.Attribute):
+            # 继承 adam_community.Tool 或类似的形式
+            if (isinstance(base.value, ast.Name) and 
+                base.value.id == 'adam_community' and 
+                base.attr == 'Tool'):
+                return True
+            # 继承 Tool 类（可能是通过 from adam_community import Tool 导入的）
+            if base.attr == 'Tool':
+                return True
+    return False
+
 def parse_python_file(file_path: Path) -> List[Dict[str, Any]]:
     """解析单个 Python 文件，提取类信息
     
@@ -281,6 +310,10 @@ def parse_python_file(file_path: Path) -> List[Dict[str, Any]]:
         
         for node in ast.walk(tree):
             if isinstance(node, ast.ClassDef):
+                # 检查类是否继承了 adam_community.Tool
+                if not _inherits_from_tool(node):
+                    continue
+                
                 # 获取类的文档字符串
                 docstring = ast.get_docstring(node) or ""
                 
@@ -330,6 +363,9 @@ def parse_python_file(file_path: Path) -> List[Dict[str, Any]]:
                     "required": []
                 }
                 
+                # 延迟导入 docstring_parser 避免模块级别的依赖问题
+                from docstring_parser import parse as dsp
+
                 # 使用 docstring_parser 解析类的文档字符串
                 docs = dsp(docstring)
                 if docs:
